==> zio-aws-firehose_2.13-7.28.26.1-sources.jar: zio/aws/firehose/model/RetryOptions.scala <==
package zio.aws.firehose.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.firehose.model.primitives.RetryDurationInSeconds
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class RetryOptions(
    durationInSeconds: Optional[RetryDurationInSeconds] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.RetryOptions = {
    import RetryOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.RetryOptions
      .builder()
      .optionallyWith(
        durationInSeconds.map(value =>
          RetryDurationInSeconds.unwrap(value): Integer
        )
      )(_.durationInSeconds)
      .build()
  }
  def asReadOnly: zio.aws.firehose.model.RetryOptions.ReadOnly =
    zio.aws.firehose.model.RetryOptions.wrap(buildAwsValue())
}
object RetryOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.RetryOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.RetryOptions =
      zio.aws.firehose.model.RetryOptions(durationInSeconds.map(value => value))
    def durationInSeconds: Optional[RetryDurationInSeconds]
    def getDurationInSeconds: ZIO[Any, AwsError, RetryDurationInSeconds] =
      AwsError.unwrapOptionField("durationInSeconds", durationInSeconds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.RetryOptions
  ) extends zio.aws.firehose.model.RetryOptions.ReadOnly {
    override val durationInSeconds: Optional[RetryDurationInSeconds] =
      zio.aws.core.internal
        .optionalFromNullable(impl.durationInSeconds())
        .map(value =>
          zio.aws.firehose.model.primitives.RetryDurationInSeconds(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.RetryOptions
  ): zio.aws.firehose.model.RetryOptions.ReadOnly = new Wrapper(impl)
}

==> zio-aws-firehose_3-5.17.104.5-sources.jar: zio/aws/firehose/model/RetryOptions.scala <==
package zio.aws.firehose.model
import java.lang.Integer
import zio.aws.firehose.model.primitives.RetryDurationInSeconds
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class RetryOptions(
    durationInSeconds: Option[RetryDurationInSeconds] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.RetryOptions = {
    import RetryOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.RetryOptions
      .builder()
      .optionallyWith(
        durationInSeconds.map(value =>
          RetryDurationInSeconds.unwrap(value): Integer
        )
      )(_.durationInSeconds)
      .build()
  }
  def asReadOnly: zio.aws.firehose.model.RetryOptions.ReadOnly =
    zio.aws.firehose.model.RetryOptions.wrap(buildAwsValue())
}
object RetryOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.RetryOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.RetryOptions =
      zio.aws.firehose.model.RetryOptions(durationInSeconds.map(value => value))
    def durationInSeconds: Option[RetryDurationInSeconds]
    def getDurationInSeconds: ZIO[Any, AwsError, RetryDurationInSeconds] =
      AwsError.unwrapOptionField("durationInSeconds", durationInSeconds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.RetryOptions
  ) extends zio.aws.firehose.model.RetryOptions.ReadOnly {
    override val durationInSeconds: Option[RetryDurationInSeconds] = scala
      .Option(impl.durationInSeconds())
      .map(value =>
        zio.aws.firehose.model.primitives.RetryDurationInSeconds(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.RetryOptions
  ): zio.aws.firehose.model.RetryOptions.ReadOnly = new Wrapper(impl)
}
